@@ -29,6 +29,11 @@ kcitemessage <- paste0("When publishing work using the Manifesto Corpus, please
                        "make sure to cite it correctly and to give the identification ",
                        "number of the corpus version used for your analysis.")
 
-message(paste(kcitemessage,
-  "You can print citation and version information with the function mp_cite().",
-  sep = "\n\n"))
+.onAttach = function(libname, pkgname) {
+  packageStartupMessage(paste(kcitemessage,
+                "You can print citation and version information with the function mp_cite().",
+                paste0(c("Note that some of the scaling/analysis algorithms provided with this package were conceptually",
+                         "developed by authors referenced in the respective function documentation. Please also",
+                         "reference them when using these algorithms."), collapse = " "),
+                sep = "\n\n"))
+}
